let hoverEnabled = false;  // Global toggle

chrome.runtime.onInstalled.addListener(() => {
  chrome.contextMenus.create({
    id: "toggle-hover",
    title: "Enable H Tag Inspector",
    contexts: ["all"]
  });

  chrome.contextMenus.create({
    id: "check-tag",
    title: "Check This H Tag (Selection)",
    contexts: ["selection"]
  });
});

chrome.contextMenus.onClicked.addListener((info, tab) => {
  if (info.menuItemId === "toggle-hover") {
    hoverEnabled = !hoverEnabled;
    const newTitle = hoverEnabled ? "Disable H Tag Inspector" : "Enable H Tag Inspector";
    chrome.contextMenus.update("toggle-hover", { title: newTitle });

    // Tell content script to enable/disable hover
    chrome.tabs.sendMessage(tab.id, { action: hoverEnabled ? "enable-hover" : "disable-hover" });
  }

  if (info.menuItemId === "check-tag") {
    chrome.scripting.executeScript({
      target: { tabId: tab.id },
      function: checkSelectedTag
    });
  }
});

chrome.commands.onCommand.addListener((command) => {
  if (command === "check-h-tag-shortcut") {
    chrome.tabs.query({ active: true, currentWindow: true }, (tabs) => {
      const tab = tabs[0];
      chrome.scripting.executeScript({
        target: { tabId: tab.id },
        function: checkSelectedTag
      });
    });
  }
});

function checkSelectedTag() {
  const selection = window.getSelection();
  if (!selection.rangeCount) return;

  const range = selection.getRangeAt(0);
  const node = range.startContainer.parentNode;
  const tag = node.tagName.toLowerCase();

  const allowedTags = ["h1", "h2", "h3", "h4", "h5", "h6", "p"];
  if (!allowedTags.includes(tag)) return;

  node.classList.add(`seo-highlight-${tag}`);

  const label = document.createElement("div");
  label.className = `seo-label seo-label-${tag}`;
  label.textContent = `${tag.toUpperCase()} Tag`;

  const style = window.getComputedStyle(node);
  if (style.position === "static") {
    node.style.position = "relative";
  }

  label.style.position = "absolute";
  label.style.top = "0";
  label.style.left = "0";
  label.style.transform = "translateY(-100%)";
  label.style.marginTop = "-4px";
  label.style.zIndex = "10000";

  node.appendChild(label);

  setTimeout(() => {
    label.remove();
    node.classList.remove(`seo-highlight-${tag}`);
    if (style.position === "static") {
      node.style.position = "";
    }
  }, 8000);
}
