let hoverEnabled = false;

function addHoverListeners() {
  document.addEventListener("mouseover", handleHover);
  document.addEventListener("mouseout", handleOut);
}

function removeHoverListeners() {
  document.removeEventListener("mouseover", handleHover);
  document.removeEventListener("mouseout", handleOut);
}

function handleHover(e) {
  const tag = e.target.tagName.toLowerCase();
  const allowedTags = ["h1", "h2", "h3", "h4", "h5", "h6", "p"];
  if (!allowedTags.includes(tag)) return;

  const node = e.target;
  node.classList.add(`seo-highlight-${tag}`);

  if (node.querySelector(`.seo-label-${tag}`)) return;

  const label = document.createElement("div");
  label.className = `seo-label seo-label-${tag}`;
  label.textContent = `${tag.toUpperCase()} Tag`;

  const style = window.getComputedStyle(node);
  if (style.position === "static") {
    node.style.position = "relative";
  }

  label.style.position = "absolute";
  label.style.top = "0";
  label.style.left = "0";
  label.style.transform = "translateY(-100%)";
  label.style.marginTop = "-4px";
  label.style.zIndex = "10000";

  node.appendChild(label);
  node.dataset.seoOriginalPosition = style.position;
}

function handleOut(e) {
  const tag = e.target.tagName.toLowerCase();
  const allowedTags = ["h1", "h2", "h3", "h4", "h5", "h6", "p"];
  if (!allowedTags.includes(tag)) return;

  const node = e.target;
  const label = node.querySelector(`.seo-label-${tag}`);
  if (label) label.remove();

  node.classList.remove(`seo-highlight-${tag}`);

  if (node.dataset.seoOriginalPosition === "static") {
    node.style.position = "";
  }
  delete node.dataset.seoOriginalPosition;
}

// Listen for toggle messages from background
chrome.runtime.onMessage.addListener((message, sender, sendResponse) => {
  if (message.action === "enable-hover") {
    hoverEnabled = true;
    addHoverListeners();
  } else if (message.action === "disable-hover") {
    hoverEnabled = false;
    removeHoverListeners();
  }
});
